<?php
/*
Plugin Name: STINGERタグ管理プラグイン3
Description: タグを管理するプラグイン
Version: 20190130
*/

if ( !defined( 'ABSPATH' ) ) {
	exit;
}

define('ST_AF_CPT', true);

define('ST_AF_CPT_WYSIWYG_ENABLE', true);

define('ST_AF_CPT_RESET_META_BOX', false);

if (!function_exists( 'st_af_cpt_get_manager_roles' )) {
	function st_af_cpt_get_manager_roles() {
	    $roles = array(
		    'administrator',
	    );

		return $roles;
    }
}

if (!function_exists('st_af_cpt_get_capabilities')) {
	function st_af_cpt_get_capabilities() {
	    $capabilities = array(
		    'edit_post'              => 'edit_' . st_af_cpt_get_post_type_name(),
		    'read_post'              => 'read_' . st_af_cpt_get_post_type_name(),
		    'delete_post'            => 'delete_' . st_af_cpt_get_post_type_name(),
		    'edit_posts'             => 'edit_' . st_af_cpt_get_post_type_name() . 's',
		    'edit_others_posts'      => 'edit_others_' . st_af_cpt_get_post_type_name() . 's',
		    'publish_posts'          => 'publish_' . st_af_cpt_get_post_type_name() . 's',
		    'read_private_posts'     => 'read_private_' . st_af_cpt_get_post_type_name() . 's',
		    'delete_posts'           => 'delete_' . st_af_cpt_get_post_type_name() . 's',
		    'delete_private_posts'   => 'delete_private_' . st_af_cpt_get_post_type_name() . 's',
		    'delete_published_posts' => 'delete_published_' . st_af_cpt_get_post_type_name() . 's',
		    'delete_others_posts'    => 'delete_others_' . st_af_cpt_get_post_type_name() . 's',
		    'edit_private_posts'     => 'edit_private_' . st_af_cpt_get_post_type_name() . 's',
		    'edit_published_posts'   => 'edit_published_' . st_af_cpt_get_post_type_name() . 's',
		    'create_posts'           => 'edit_' . st_af_cpt_get_post_type_name() . 's',
	    );

	    return $capabilities;
    }
}

if (!function_exists('st_af_cpt_get_taxonomy_capabilities')) {
	function st_af_cpt_get_taxonomy_capabilities() {
		$capabilities = array(
			'manage_terms' => 'manage_' .st_af_cpt_get_post_type_name() . '_terms',
			'edit_terms'   => 'manage_' .st_af_cpt_get_post_type_name() . '_terms',
			'delete_terms' => 'manage_' .st_af_cpt_get_post_type_name() . '_terms',
			'assign_terms' => 'edit_' . st_af_cpt_get_post_type_name() . 's',
		);

		return $capabilities;
	}
}

if (!function_exists('st_af_cpt_init_capabilities')) {
	function st_af_cpt_init_capabilities() {
		/** @var WP_Roles $wp_roles */
		global $wp_roles;

		if ( !isset( $wp_roles ) ) {
			$wp_roles = new WP_Roles();
		}

		$managerRoles = st_af_cpt_get_manager_roles();
		$capabilities = array_merge( st_af_cpt_get_capabilities(), st_af_cpt_get_taxonomy_capabilities() );

		foreach ( array_keys($wp_roles->roles) as $role_name ) {
			$role = get_role($role_name);

			if (in_array($role_name, $managerRoles, true)) {
				foreach ( $capabilities as $capability ) {
					$role->add_cap($capability);
				}
			} else {
				foreach ( $capabilities as $capability ) {
					$role->remove_cap($capability);
				}
			}
		}
	}
}

add_action( 'init', 'st_af_cpt_init_capabilities' );

if (!function_exists('st_af_cpt_enqueue_styles')) {
	function st_af_cpt_enqueue_styles() {
		wp_register_style(
			'st-af-cpt',
			plugin_dir_url( __FILE__ ) . 'assets/css/style.css',
			array(),
			'1.0.0'
		);

		wp_enqueue_style( 'st-af-cpt' );
	}
}

add_action( 'wp_enqueue_scripts', 'st_af_cpt_enqueue_styles' );

if ( ! function_exists( 'st_af_cpt_display_notification' ) ) {
	function st_af_cpt_display_notification() {
		if ( ! function_exists( 'get_current_screen' ) ) {
			return;
		}

		$screen = get_current_screen();

		if ( ! st_af_cpt_is_cpt_post_screen( $screen ) ) {
			return;
		}

		?>
		<div class="notice notice-success">
			<p>
				<a href="//on-store.net/affiliaterun3/" rel="nofollow" target="_blank">リンク計測バージョンにアップデートする</a>
			</p>
		</div>
		<?php
	}
}

add_action( 'admin_notices', 'st_af_cpt_display_notification' );

if ( !function_exists( 'st_af_cpt_get_cat_tax_name' ) ) {
	function st_af_cpt_get_cat_tax_name() {
		return 'st_af_category';
	}
}

if ( !function_exists( 'st_af_cpt_get_tag_tax_name' ) ) {
	function st_af_cpt_get_tag_tax_name() {
		return 'st_af_tags';
	}
}

if ( !function_exists( 'st_af_cpt_get_post_type_name' ) ) {
	function st_af_cpt_get_post_type_name() {
		return 'st_af';
	}
}

if ( !function_exists( 'st_af_cpt_register_category' ) ) {
	function st_af_cpt_register_category() {
		$category_name = st_af_cpt_get_cat_tax_name();

		$args = array(
			'public'                => false,
			'hierarchical'          => true,
			'show_ui'               => true,
			'show_in_menu'          => true,
			'show_in_nav_menus'     => false,
			'show_tagcloud'         => false,
			'show_in_quick_edit'    => true,
			'show_admin_column'     => true,
			'meta_box_cb'           => null,
			'capabilities'          => st_af_cpt_get_taxonomy_capabilities(),
			'rewrite'               => true,
			'query_var'             => $category_name,
			'update_count_callback' => '',
		);

		register_taxonomy( $category_name, st_af_cpt_get_post_type_name(), $args );
	}
}

add_action( 'init', 'st_af_cpt_register_category' );

if ( !function_exists( 'st_af_cpt_register_tag' ) ) {
	function st_af_cpt_register_tag() {
		$tag_name = st_af_cpt_get_tag_tax_name();

		$args = array(
			'public'                => false,
			'hierarchical'          => false,
			'show_ui'               => true,
			'show_in_menu'          => true,
			'show_in_nav_menus'     => false,
			'show_tagcloud'         => true,
			'show_in_quick_edit'    => true,
			'show_admin_column'     => true,
			'meta_box_cb'           => null,
			'capabilities'          => st_af_cpt_get_taxonomy_capabilities(),
			'rewrite'               => true,
			'query_var'             => $tag_name,
			'update_count_callback' => '',
		);

		register_taxonomy( $tag_name, st_af_cpt_get_post_type_name(), $args );
	}
}

add_action( 'init', 'st_af_cpt_register_tag' );

if ( !function_exists( 'st_af_cpt_register_post_type' ) ) {
	function st_af_cpt_register_post_type() {
		$labels = array(
			'name'               => 'STINGERタグ',
			'singular_name'      => 'STINGERタグ',
			'add_new'            => '新規追加',
			'add_new_item'       => '新規STINGERタグを追加',
			'edit_item'          => 'STINGERタグの編集',
			'new_item'           => '新規STINGERタグ',
			'view_item'          => 'STINGERタグを表示',
			'search_items'       => 'STINGERタグを検索',
			'not_found'          => 'STINGERタグが見つかりませんでした。',
			'not_found_in_trash' => 'ゴミ箱内にSTINGERタグが見つかりませんでした。',
			'parent_item_colon'  => '親STINGERタグ:',
			'all_items'          => 'STINGERタグ一覧',
		);

		$args = array(
			'labels'               => $labels,
			'description'          => 'STINGERタグ',
			'public'               => false,
			'hierarchical'         => true,
			'exclude_from_search'  => true,
			'publicly_queryable'   => false,
			'show_ui'              => true,
			'show_in_menu'         => true,
			'show_in_nav_menus'    => false,
			'show_in_admin_bar'    => true,
			'menu_position'        => null,
			'menu_icon'            => null,
			'capability_type'      => st_af_cpt_get_post_type_name(),
			'capabilities'         => array(),
			'map_meta_cap'         => true,
			'supports'             => array( 'title', 'revisions', 'author', 'custom-fields' ),
			'register_meta_box_cb' => null,
			'taxonomies'           => array( st_af_cpt_get_cat_tax_name() ),
			'has_archive'          => false,
			'rewrite'              => true,
			'query_var'            => true,
			'can_export'           => true,
			'delete_with_user'     => null,
		);

		register_post_type( st_af_cpt_get_post_type_name(), $args );
	}
}

add_action( 'init', 'st_af_cpt_register_post_type' );

if ( !function_exists( 'st_af_cpt_should_be_reset_meta_box' ) ) {
	function st_af_cpt_should_be_reset_meta_box() {
		return ( defined( 'ST_AF_CPT_RESET_META_BOX' ) && ST_AF_CPT_RESET_META_BOX );
	}
}

if ( !function_exists( 'st_af_cpt_reset_hidden_meta_box' ) ) {
	function st_af_cpt_reset_hidden_meta_box() {
		if ( !$user = wp_get_current_user() ) {
			return;
		}

		update_user_option( $user->ID, 'metaboxhidden_' . st_af_cpt_get_post_type_name(), array( 'postcustom' ), true );
	}

	if ( st_af_cpt_should_be_reset_meta_box() ) {
		st_af_cpt_reset_hidden_meta_box();
	}
}

if (!function_exists( 'st_af_cpt_is_cpt_screen' )) {
	function st_af_cpt_is_cpt_screen( $screen ) {
		return is_admin() &&
			   ( $screen && isset( $screen->post_type ) ) &&
			   ( $screen->post_type === st_af_cpt_get_post_type_name() );
    }
}

if ( ! function_exists( 'st_af_cpt_is_cpt_post_screen' ) ) {
	function st_af_cpt_is_cpt_post_screen( $screen ) {
		$has_base     = ( $screen && isset( $screen->base ) );
		$is_base_post = ( $has_base && $screen->base === 'post' );
		$is_base_edit = ( $has_base && $screen->base === 'edit' );
		$is_editable  = ( $is_base_post || $is_base_edit );

		return ( st_af_cpt_is_cpt_screen( $screen ) && $is_editable );
	}
}

if (!function_exists( 'st_af_cpt_is_editable_cpt_screen' )) {
	function st_af_cpt_is_editable_cpt_screen( $screen ) {
		$is_base_post        = ( $screen && isset( $screen->base ) && $screen->base === 'post' );
		$is_parent_base_edit = ( $screen && isset( $screen->parent_base ) && $screen->parent_base === 'edit' );
		$is_editable         = ( $is_base_post || $is_parent_base_edit );

		return ( st_af_cpt_is_cpt_screen( $screen ) && $is_editable );
	}
}

if ( !function_exists( 'st_af_cpt_hidden_meta_boxes' ) ) {
	function st_af_cpt_hidden_meta_boxes( $hidden, $screen ) {
		if ( st_af_cpt_is_editable_cpt_screen( $screen ) ) {
			$hidden = array_merge( $hidden, array( 'postcustom' ) );
		}

		return $hidden;
	}
}

add_filter( 'default_hidden_meta_boxes', 'st_af_cpt_hidden_meta_boxes', 10, 2 );

if ( !function_exists( 'st_af_cpt_flusth' ) ) {
	function st_af_cpt_flusth() {
		flush_rewrite_rules();
	}
}

add_action( 'after_switch_theme', 'st_af_cpt_flusth' );

if ( !function_exists( 'st_af_cpt_output_tag_meta_box' ) ) {
	function st_af_cpt_output_tag_meta_box( $post ) {
		?>

		<div style="padding:10px 20px;background:#f3f3f3;border-radius:8px;">
		<p><i class="fa fa-files-o" aria-hidden="true"></i><b>以下のショートコードを表示したい箇所に記入して下さい</b></p>
		<p>
			ショートコード：&nbsp;<code>[<?php echo esc_html(st_af_cpt_get_shortcode_name()); ?> id="<?php echo esc_html( $post->ID ); ?>"]</code>
			<?php if ( trim( $post->post_name ) !== '' ) :    // スラッグがある場合 ?>
				または <code>[<?php echo esc_html(st_af_cpt_get_shortcode_name()); ?> name="<?php echo esc_html( $post->post_name ); ?>"]</code>
			<?php endif; ?>
		</p>
		<p>
			phpテンプレートに直接記入する場合は<code>&lt;?php echo do_shortcode('[<?php echo esc_html(st_af_cpt_get_shortcode_name()); ?> id="<?php echo esc_html( $post->ID ); ?>"]'); ?&gt;</code>
		</p>
		</div>

		<input type="hidden" name="st_af_cpt_af__is_tag_meta_box" value="1">

		<?php wp_nonce_field('st_af_cpt_save', 'st_af_cpt_nonce'); ?>

		<?php
	}
}

if ( !function_exists( 'st_af_cpt_output_raw_meta_box' ) ) {
	function st_af_cpt_output_raw_meta_box( $post ) {
		$raw_html = trim( get_post_meta( $post->ID, 'raw_html', true ) );

		$raw_html_text_editor = (int) (bool) trim( get_post_meta( $post->ID, 'raw_html_text_editor', true ) );
		?>

		<p>
			<label for="st_af_cpt_af_raw_html">※ここに記入がある場合は再優先されます（その他の記述は表示されません）</label>
		</p>
		<p>
			<?php do_action( 'st_af_cpt_editor', 'raw_html', 'st_af_cpt_af_raw_html', $raw_html ); ?>
		</p>

		<p>
			<label>
				<input type="checkbox" name="st_af_cpt_af_raw_html_text_editor" value="1"<?php checked($raw_html_text_editor); ?>> ビジュアルエディタを停止する（注：自動整形の影響を受けなくなります）
			</label>
		</p>

		<input type="hidden" name="st_af_cpt_af__is_raw_meta_box" value="1">

		<?php wp_nonce_field( 'st_af_cpt_save', 'st_af_cpt_nonce' ); ?>

		<?php if ($raw_html_text_editor): ?>
			<style>
				#st_af_cpt_af_raw_html-tmce,
				#wp-st_af_cpt_af_raw_html-wrap .mce-edit-top-part,
				#wp-st_af_cpt_af_raw_html-wrap .mce-edit-area {
					display: none;
				}
			</style>

			<script>
				(function (window, document, $, undefined) {
					'use strict';

					$(window).on('load', function () {
						$('#st_af_cpt_af_raw_html-html').click();
					});
				}(window, window.document, jQuery));
			</script>
		<?php endif; ?>

		<?php
	}
}

if ( !function_exists( 'st_af_cpt_output_template_meta_box' ) ) {

	function st_af_cpt_output_template_meta_box( $post ) {
		$heading = trim( get_post_meta( $post->ID, 'heading', true ) );

		$star = (int) get_post_meta( $post->ID, 'star', true );

		$banner_html = trim( get_post_meta( $post->ID, 'banner_html', true ) );

		$link_html = trim( get_post_meta( $post->ID, 'link_html', true ) );

		$description = trim( get_post_meta( $post->ID, 'description', true ) );

		$description_2 = trim( get_post_meta( $post->ID, 'description_2', true ) );

		$link_uri = trim( get_post_meta( $post->ID, 'link_uri', true ) );

		$link_uri_title = trim( get_post_meta( $post->ID, 'link_uri_title', true ) );

		$nofollow = (int) (bool) trim( get_post_meta( $post->ID, 'nofollow', true ) );
		?>

		<p>CTAレイアウトで表示されます（AFFINGERではランキング）</p>
		<p>
			<label for="st_af_cpt_af_heading">見出し</label>
		</p>
		<p>
			<input type="text" id="st_af_cpt_af_heading" name="st_af_cpt_af_heading"
				   value="<?php echo esc_attr( $heading ); ?>" style="width:100%">
		</p>

		<p>
			<label for="st_af_cpt_af_start">スター※任意</label>
		</p>
		<p>
			<input type="radio" name="st_af_cpt_af_star" value="5" <?php checked(5, $star); ?>> 5
			<input type="radio" name="st_af_cpt_af_star" value="4" <?php checked(4, $star); ?>> 4
			<input type="radio" name="st_af_cpt_af_star" value="3" <?php checked(3, $star); ?>> 3
			<input type="radio" name="st_af_cpt_af_star" value="2" <?php checked(2, $star); ?>> 2
			<input type="radio" name="st_af_cpt_af_star" value="1" <?php checked(1, $star); ?>> 1
			<input type="radio" name="st_af_cpt_af_star" value="" <?php checked(0, $star); ?>> 非表示
		</p>

		<p>
			<label for="st_af_cpt_af_banner_html"><b>画像バナー</b>（画像リンク又はASPのバナーコードを記入して下さい。※iframe及びscriptタイプは非対応です）</label>
		</p>
		<p>
			<input type="text" id="st_af_cpt_af_banner_html" name="st_af_cpt_af_banner_html"
				   value="<?php echo esc_attr( $banner_html ); ?>" style="width:100%">
		</p>

		<?php if ( $banner_html !== '' ) : ?>
			<p><?php echo $banner_html; ?><br>※バナーが正常に表示されない場合はコードに誤りがある可能性があります。</p>
		<?php endif; ?>

		<p>
			<label for="st_af_cpt_af_link_html"><b>文字リンク</b>（リンクタグで囲まれたテキスト又はASPのテキストリンクコードを記入して下さい。）</label>
		</p>
		<p>
			<input type="text" id="st_af_cpt_af_link_html" name="st_af_cpt_af_link_html"
				   value="<?php echo esc_attr( $link_html ); ?>" style="width:100%">
		</p>

		<?php if ( $link_html !== '' ) : ?>
			<p>現在のリンク：&nbsp;<?php echo $link_html; ?></p>
		<?php endif ?>

		<p>
			<label for="st_af_cpt_af_description"><b>説明①</b>（AFFINGER：バナーの右 STINGER PRO：バナーの下に表示） <span style="color: #ff0000">※「画像バナー」に入力が無い場合は表示されません</span></label>
		</p>
		<p>
			<?php do_action( 'st_af_cpt_editor', 'description', 'st_af_cpt_af_description', $description ); ?>
		</p>

		<p>
			<label for="st_af_cpt_af_description_2"><b>説明②</b>（AFFINGER：バナーの下 STINGER PRO：説明①の下に表示）</label>
		</p>
		<p>
			<?php do_action( 'st_af_cpt_editor', 'description_2', 'st_af_cpt_af_description_2', $description_2 ); ?>
		</p>

		<p>
			<label for="st_af_cpt_af_link_uri"><b>詳細ページへのリンクURL</b>（※URLのみを記入）</label>
		</p>
		<p>
			<input type="url" id="st_af_cpt_af_link_uri" name="st_af_cpt_af_link_uri"
				   value="<?php echo esc_attr( $link_uri ); ?>" style="width:100%" placeholder="http://exsample.com">
		</p>

		<?php if ( $link_uri !== '' ) : ?>
			<p>現在のリンクURL：&nbsp;<?php echo esc_url( $link_uri ); ?></p>
		<?php endif; ?>

		<p>
			<label for="st_af_cpt_af_link_uri_title">詳細ページリンクボタンの表示テキスト</label>
		</p>

		<p>
			<input type="text" id="st_af_cpt_af_link_uri_title" name="st_af_cpt_af_link_uri_title"
				   value="<?php echo esc_attr( $link_uri_title ); ?>" style="width:100%" placeholder="詳細ページへ">
		</p>

		<p>
			<label><input type="checkbox" name="st_af_cpt_af_nofollow" value="1"<?php checked($nofollow); ?>> 詳細ページへのリンクにnofollowを設定する</label>
		</p>

		<input type="hidden" name="st_af_cpt_af__is_template_meta_box" value="1">

		<?php wp_nonce_field('st_af_cpt_save', 'st_af_cpt_nonce'); ?>

		<?php
	}
}

if ( !function_exists( 'st_af_cpt_output_memo_meta_box' ) ) {
	function st_af_cpt_output_memo_meta_box( $post ) {
		$private_note = trim( get_post_meta( $post->ID, 'private_note', true ) );

		?>

		<p>
			<?php do_action( 'st_af_cpt_editor', 'private_note', 'st_af_cpt_af_private_note', $private_note ); ?>
		</p>

		<input type="hidden" name="st_af_cpt_af__is_memo_meta_box" value="1">

		<?php wp_nonce_field('st_af_cpt_save', 'st_af_cpt_nonce'); ?>

		<?php
	}
}

if ( !function_exists( 'st_af_cpt_add_meta_box' ) ) {

	function st_af_cpt_add_meta_box() {
		add_meta_box(
			'st-af-cpt-af-tag',
			'<i class="fa fa-thumb-tack" aria-hidden="true"></i>タグ管理',
			'st_af_cpt_output_tag_meta_box',
			st_af_cpt_get_post_type_name(),
			'normal'
		);

		add_meta_box(
			'st-af-cpt-af-raw',
			'<i class="fa fa-code" aria-hidden="true"></i>単発コード',
			'st_af_cpt_output_raw_meta_box',
			st_af_cpt_get_post_type_name(),
			'normal'
		);

		add_meta_box(
			'st-af-cpt-af-template',
			'<i class="fa fa-list-alt" aria-hidden="true"></i>デザイン済みテンプレート作成',
			'st_af_cpt_output_template_meta_box',
			st_af_cpt_get_post_type_name(),
			'normal'
		);

		add_meta_box(
			'st-af-cpt-af-memo',
			'<i class="fa fa-sticky-note-o" aria-hidden="true"></i>メモ (非公開)',
			'st_af_cpt_output_memo_meta_box',
			st_af_cpt_get_post_type_name(),
			'normal'
		);
	}
}

add_action( 'add_meta_boxes', 'st_af_cpt_add_meta_box' );

if ( !function_exists( 'st_af_cpt_save' ) ) {

	function st_af_cpt_save( $post_id ) {
		$nonce = (string) filter_input( INPUT_POST, 'st_af_cpt_nonce' );

		if ( $nonce === '' ) {
			return;
		}

		if ( !wp_verify_nonce( $nonce, 'st_af_cpt_save' ) ) {
			return;
		}

		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}

		if ( !current_user_can( 'edit_post', $post_id ) ) {
			return;
		}

		if ((bool) filter_input(INPUT_POST, 'st_af_cpt_af__is_raw_meta_box')) {

			$raw_html = (string) filter_input( INPUT_POST, 'st_af_cpt_af_raw_html' );

			$raw_html_text_editor = (int) (bool) filter_input( INPUT_POST, 'st_af_cpt_af_raw_html_text_editor' );

			update_post_meta( $post_id, 'raw_html', $raw_html );
			update_post_meta( $post_id, 'raw_html_text_editor', $raw_html_text_editor );
		}

		if ((bool) filter_input(INPUT_POST, 'st_af_cpt_af__is_template_meta_box')) {

			$heading = (string) filter_input( INPUT_POST, 'st_af_cpt_af_heading' );
			$heading = sanitize_text_field( $heading );

			$star = filter_input( INPUT_POST, 'st_af_cpt_af_star' );
			$star = min( max( absint( $star ), 0 ), 5 );    // 0〜5

			$banner_html = (string) filter_input( INPUT_POST, 'st_af_cpt_af_banner_html' );

			$link_html = (string) filter_input( INPUT_POST, 'st_af_cpt_af_link_html' );

			$description = (string) filter_input( INPUT_POST, 'st_af_cpt_af_description' );

			$description_2 = (string) filter_input( INPUT_POST, 'st_af_cpt_af_description_2' );

			$link_uri = (string) filter_input( INPUT_POST, 'st_af_cpt_af_link_uri' );

			$link_uri_title = (string) filter_input( INPUT_POST, 'st_af_cpt_af_link_uri_title' );
			$link_uri_title = sanitize_text_field( $link_uri_title );

			$nofollow = (int) (bool) filter_input( INPUT_POST, 'st_af_cpt_af_nofollow' );

			update_post_meta( $post_id, 'heading', $heading );
			update_post_meta( $post_id, 'star', $star );
			update_post_meta( $post_id, 'banner_html', $banner_html );
			update_post_meta( $post_id, 'link_html', $link_html );
			update_post_meta( $post_id, 'description', $description );
			update_post_meta( $post_id, 'description_2', $description_2 );
			update_post_meta( $post_id, 'link_uri', $link_uri );
			update_post_meta( $post_id, 'link_uri_title', $link_uri_title );
			update_post_meta( $post_id, 'nofollow', $nofollow );
		}

		if ((bool) filter_input(INPUT_POST, 'st_af_cpt_af__is_memo_meta_box')) {
			$private_note = (string) filter_input( INPUT_POST, 'st_af_cpt_af_private_note' );

			update_post_meta( $post_id, 'private_note', $private_note );
		}
	}
}

add_action( 'save_post_' . st_af_cpt_get_post_type_name(), 'st_af_cpt_save' );

if ( ! function_exists( '_st_af_cpt_is_list_page' ) ) {

	function _st_af_cpt_is_list_page() {
		if ( ! is_admin() ) {
			return false;
		}

		if ( ! function_exists( 'get_current_screen' ) ) {
			return false;
		}

		$screen = get_current_screen();

		if ( ! $screen || ! isset( $screen->id ) ) {
			return false;
		}

		return ( $screen->id === 'edit-' . st_af_cpt_get_post_type_name() );
	}
}

if ( ! function_exists( 'st_af_cpt_manage_sortable_columns' ) ) {

	function st_af_cpt_manage_sortable_columns( array $sortable_columns = array() ) {
		if ( array_key_exists( 'date', $sortable_columns ) &&
		     is_array( $sortable_columns['date'] ) && count( $sortable_columns['date'] ) >= 2
		) {
			$sortable_columns['date'][1] = false;
		}

		return $sortable_columns;
	}
}

add_filter( 'manage_edit-' . st_af_cpt_get_post_type_name() . '_sortable_columns', 'st_af_cpt_manage_sortable_columns' );

if ( ! function_exists( '_st_af_cpt_get_search_post_ids' ) ) {

	function _st_af_cpt_get_search_post_ids( $wp_query, $s ) {
		$ids = [];

		if ( trim( $s ) === '' ) {
			return $ids;
		}

		$args = [];

		foreach ( $wp_query->query as $key => $value ) {
			$args[ $key ] = $value;
		}

		unset( $args['s'] );

		// ID
		if ( ctype_digit( $s ) ) {
			$ids[] = (int) $s;
		}

		$posts_where_like_name = function ( $where, $wp_query ) {
			global $wpdb;

			$name = $wp_query->get( 'name' );

			if ( $name ) {
				$where .= $wpdb->prepare( ' OR post_name LIKE %s', '%' . $wpdb->esc_like( $name ) . '%' );
			}

			return $where;
		};

		add_filter( 'posts_where', $posts_where_like_name, 10, 2 );

		$name_query = new WP_Query( array_merge(
			$args,
			array(
				'fields' => 'ids',
				'name'   => $s,
			)
		) );

		remove_filter( 'posts_where', $posts_where_like_name );

		$ids = array_merge( $ids, $name_query->posts );

		$search_query = new WP_Query( array_merge(
			$args,
			array(
				'fields' => 'ids',
				's'      => $s,
			)
		) );

		$ids = array_merge( $ids, $search_query->posts );

		return array_unique( $ids );
	}
}

if ( ! function_exists( 'st_af_cpt_pre_get_posts' ) ) {

	function st_af_cpt_pre_get_posts( WP_Query $wp_query ) {
		if ( ! _st_af_cpt_is_list_page() || ! $wp_query->is_main_query() ) {
			return $wp_query;
		}

		if ( (string) filter_input( INPUT_GET, 'orderby' ) === '' &&
		     (string) filter_input( INPUT_GET, 'order' ) === ''
		) {
			$wp_query->set( 'orderby', 'date' );
			$wp_query->set( 'order', 'DESC' );
		}

		$s   = $wp_query->get( 's', '' );
		$ids = _st_af_cpt_get_search_post_ids( $wp_query, $s );

		if ( count( $ids ) > 0 ) {
			$wp_query->set( 'post__in', $ids );
			$wp_query->set( 's', '' );

			add_filter( 'get_search_query',
				function () use ( $s ) {
					return $s;
				}
			);
		}

		return $wp_query;
	}
}

add_action( 'pre_get_posts', 'st_af_cpt_pre_get_posts' );

if ( ! function_exists( 'st_af_cpt_restrict_manage_posts' ) ) {

	function st_af_cpt_restrict_manage_posts() {
		global $wp_query;

		$list_cats = function ( $element ) {
			return mb_strimwidth( $element, 0, 40, '...', 'UTF-8' );
		};

		if ( ! _st_af_cpt_is_list_page() ) {
			return;
		}

		add_filter( 'list_cats', $list_cats );

		$category_name     = st_af_cpt_get_cat_tax_name();
		$category_taxonomy = get_taxonomy( $category_name );

		$category_dropdown = wp_dropdown_categories( [
			'show_option_all' => $category_taxonomy->labels->all_items,
			'taxonomy'        => $category_name,
			'name'            => $category_name,
			'orderby'         => 'name',
			'selected'        => isset( $wp_query->query[ $category_name ] ) ? $wp_query->query[ $category_name ] : 0,
			'hierarchical'    => true,
			'depth'           => 0,
			'show_count'      => false,
			'hide_empty'      => false,
			'echo'            => false,
			'value_field'     => 'slug',
		] );

		if ( preg_match( '!</option>!', $category_dropdown ) ) {
			echo $category_dropdown;
		}

		$tag_name     = st_af_cpt_get_tag_tax_name();
		$tag_taxonomy = get_taxonomy( $tag_name );

		$tag_dropdown = wp_dropdown_categories( [
			'show_option_all' => $tag_taxonomy->labels->all_items,
			'taxonomy'        => $tag_name,
			'name'            => $tag_name,
			'orderby'         => 'name',
			'selected'        => isset( $wp_query->query[ $tag_name ] ) ? $wp_query->query[ $tag_name ] : 0,
			'hierarchical'    => true,
			'depth'           => 0,
			'show_count'      => false,
			'hide_empty'      => false,
			'echo'            => false,
			'value_field'     => 'slug',
		] );

		if ( preg_match( '!</option>!', $tag_dropdown ) ) {
			echo $tag_dropdown;
		}

		remove_filter( 'list_cats', $list_cats );
	}
}

add_action( 'restrict_manage_posts', 'st_af_cpt_restrict_manage_posts' );

if ( ! function_exists( 'st_af_cpt_parse_query' ) ) {

	function st_af_cpt_parse_query( WP_Query $wp_query ) {
		if ( ! _st_af_cpt_is_list_page() || ! $wp_query->is_main_query() ) {
			return $wp_query;
		}

		$category_name = st_af_cpt_get_cat_tax_name();

		if ( isset( $wp_query->query_vars[ $category_name ] ) ) {
			$category_term = get_term_by( 'slug', $wp_query->query_vars[ $category_name ], $category_name );

			if ( $category_term === false ) {
				unset( $wp_query->query_vars[ $category_name ] );
			}
		}

		$tag_name = st_af_cpt_get_cat_tax_name();

		if ( isset( $wp_query->query_vars[ $tag_name ] ) ) {
			$tag_term = get_term_by( 'slug', $wp_query->query_vars[ $tag_name ], $tag_name );

			if ( $tag_term === false ) {
				unset( $wp_query->query_vars[ $tag_name ] );
			}
		}

		return $wp_query;
	}
}

add_action( 'parse_query', 'st_af_cpt_parse_query' );

if ( !function_exists( 'st_af_cpt_wysiwyg_is_enabled' ) ) {

	function st_af_cpt_wysiwyg_is_enabled() {
		$is_wysiwyg_enabled = ( defined( 'ST_AF_CPT_WYSIWYG_ENABLE' ) && ST_AF_CPT_WYSIWYG_ENABLE );

		if ( ! is_admin() || ! function_exists( 'get_current_screen' ) ) {
			return $is_wysiwyg_enabled;
		}

		$screen             = get_current_screen();
		$is_editable_screen = st_af_cpt_is_editable_cpt_screen( $screen );

		return ( $is_editable_screen && $is_wysiwyg_enabled );
	}
}

if ( !function_exists( 'st_af_cpt_editor' ) ) {

	function st_af_cpt_editor($location = null, $name = null, $content = '') {
		if ($location === null || $name === null) {
			return;
		}

		do_action('st_af_cpt_' . $location . '_editor', $location, $name, $content);
	}
}

add_action('st_af_cpt_editor', 'st_af_cpt_editor', 10, 3);

if ( !function_exists( 'st_af_kanri_output_default_editor' ) ) {

	function st_af_cpt_default_editor( $location, $name, $content = '' ) {
		?>
		<textarea name="<?php echo esc_attr( $name ); ?>" cols="50" rows="10" style="width:100%"><?php echo esc_html( $content ); ?></textarea>
		<?php
	}
}

if ( !function_exists( 'st_af_cpt_wysiwyg_get_settings' ) ) {

	function st_af_cpt_wysiwyg_get_settings( $location = null, $name = null ) {
		$settings = array(
				'wpautop'       => true,
				'media_buttons' => true,
				'textarea_rows' => 10,
		);

		if ( $name !== null ) {
			$settings[ 'textarea_name' ] = $name;
		}

		return $settings;
	}
}

if ( !function_exists( 'st_af_cpt_wysiwyg_editor' ) ) {

	function st_af_cpt_wysiwyg_editor( $location = null, $name = null, $content = '' ) {
		$editor_id = ( $location !== null ) ? ( 'st_af_cpt_af_' . $location ) : 'st_af_cpt_af';
		$settings  = st_af_cpt_wysiwyg_get_settings( $location, $name );

		wp_editor( $content, $editor_id, $settings );
	}
}

add_action( 'st_af_cpt_description_editor', 'st_af_cpt_wysiwyg_editor', 10, 3 );
add_action( 'st_af_cpt_description_2_editor', 'st_af_cpt_wysiwyg_editor', 10, 3 );
add_action( 'st_af_cpt_private_note_editor', 'st_af_cpt_wysiwyg_editor', 10, 3 );

if (!function_exists('st_af_cpt_manage_raw_html_editor')) {
    function st_af_cpt_manage_raw_html_editor() {
	    if ( st_af_cpt_wysiwyg_is_enabled() ) {
		    add_action( 'st_af_cpt_raw_html_editor', 'st_af_cpt_wysiwyg_editor', 10, 3 );
	    } else {
		    add_action( 'st_af_cpt_raw_html_editor', 'st_af_cpt_default_editor', 10, 3 );
	    }
    }
}

add_action('admin_head', 'st_af_cpt_manage_raw_html_editor');

if ( !function_exists( 'st_af_cpt_get_shortcode_name' ) ) {

	function st_af_cpt_get_shortcode_name() {
		return 'st_af';
	}
}

if ( !function_exists( 'st_af_cpt_find_post' ) ) {

	function st_af_cpt_find_post( $id = null, $name = '' ) {
		$wp_query = new WP_Query(
			array(
				'posts_per_page' => 1,
				'post_type'      => st_af_cpt_get_post_type_name(),
				'p'              => $id,
				'name'           => $name,
				'has_password'   => false,
			)
		);

		if ( $wp_query->have_posts() ) {
			return $wp_query->next_post();
		}

		return null;
	}
}

if (!function_exists('st_af_cpt_get_star_html')) {

	function st_af_cpt_get_star_html($number, $max = 5) {
	    $number = min( max( absint( $number ), 0 ), $max );    // 0〜5

	    if ($number === 0) {
			return  '';
	    }

	    $html = '<br /><span class="st-star">';
	    $html .= str_repeat('<i class="fa fa-star"></i>', $number);
	    $html .= str_repeat('<i class="fa fa-star-o"></i>', $max - $number);
	    $html .= '</span>';

		return $html;
    }
}

if ( !function_exists( 'st_af_cpt_get_shortcode' ) ) {

	function st_af_cpt_get_shortcode( $post ) {

		$heading      = trim( get_post_meta( $post->ID, 'heading', true ) );
		$heading_html = esc_html( $heading );
		$heading_attr = esc_attr( $heading );

		$star      = (int) get_post_meta( $post->ID, 'star', true );
		$star_html = st_af_cpt_get_star_html( $star );

		$description      = trim( get_post_meta( $post->ID, 'description', true ) );
		$description_html = $description;
		$description_html = apply_filters( 'the_content', $description_html );
		$description_html = str_replace( ']]>', ']]&gt;', $description_html );

		$description_2      = trim( get_post_meta( $post->ID, 'description_2', true ) );
		$description_2_html = $description_2;
		$description_2_html = apply_filters( 'the_content', $description_2_html );
		$description_2_html = str_replace( ']]>', ']]&gt;', $description_2_html );

		$banner_html = trim( get_post_meta( $post->ID, 'banner_html', true ) );

		$link_html = trim( get_post_meta( $post->ID, 'link_html', true ) );

		$link_uri      = trim( get_post_meta( $post->ID, 'link_uri', true ) );
		$link_uri_html = $link_uri;

		$link_uri_title      = trim( get_post_meta( $post->ID, 'link_uri_title', true ) );
		$link_uri_title_html = $link_uri_title;

		if ( trim($link_uri_title) === "" ){
			$link_uri_title_html = "詳細ページへ";
		}else{
			$link_uri_title_html = esc_html( $link_uri_title );
		}

		$nofollow = (int) (bool) trim( get_post_meta( $post->ID, 'nofollow', true ) );
		$rel      = $nofollow ? ' rel="nofollow"' : '';

		$raw_html_text_editor = (int) (bool) trim( get_post_meta( $post->ID, 'raw_html_text_editor', true ) );

		$raw_html      = trim( get_post_meta( $post->ID, 'raw_html', true ) );
		$raw_html_html = $raw_html;

		if ( $raw_html_text_editor ) {
			$raw_html_html = do_shortcode( $raw_html );
		} else {
			$raw_html_html = apply_filters( 'the_content', $raw_html_html );
			$raw_html_html = str_replace( ']]>', ']]&gt;', $raw_html_html );
		}

		$edit_button = '';

		if ( current_user_can( 'edit_' . st_af_cpt_get_post_type_name(), $post->ID ) ) {
			$edit_url = get_edit_post_link( $post );
			$title    = esc_attr( get_the_title( $post ) );;

			$edit_button = <<<HTML
<button class="st-af-cpt-edit-button" type="button" onclick="window.open('{$edit_url}'); return false;" title="{$title}">
	[タグ編集]
</button>
HTML;
		}

		if ( $raw_html !== '' ) {
			return $raw_html_html . $edit_button;
		}

		$has_both           = ( $link_html !== '' && $link_uri !== '' );
		$has_only_link_html = ( $link_html !== '' && $link_uri === '' );
		$has_only_link_uri  = ( $link_html === '' && $link_uri !== '' );

		if( $heading_html !== '' ){
			$html = <<<HTML
			<div class="rankst-box post">
			<h4 class="rankh4">{$heading_html}{$star_html}</h4>
HTML;
		}else{
			$html = <<<HTML
			<div class="rankst-box post">
HTML;
		}

		if ($banner_html !== '' || $description_html !== '') {
			$html .= <<<HTML
	<div class="clearfix rankst">
		<div class="rankst-l">
			{$banner_html}
		</div>
		<div class="rankst-r"><div class="rankst-cont">{$description_html}</div></div>
	</div>
HTML;
		}

		if ($description_2_html !== '') {
			$html .= <<<HTML
	<div class="rankst-contb">{$description_2_html}</div>
HTML;
		}

		if ( $has_both ) {
			$html .= <<<HTML
	<div class="clearfix rankst">
		<div class="rankstlink-l">
			<p><a href="{$link_uri_html}"{$rel}>{$link_uri_title_html}</a></p>
		</div>
		<div class="rankstlink-r">
			<p>{$link_html}</p>
		</div>
	</div>
HTML;
		} elseif ( $has_only_link_html ) {
			$html .= <<<HTML
	<div class="clearfix rankst">
		<div class="rankstlink-a">
			<p>{$link_html}</p>
		</div>
	</div>
HTML;
		} elseif ( $has_only_link_uri ) {
			$html .= <<<HTML
	<div class="clearfix rankst">
		<div class="rankstlink-b">
			<p><a href="{$link_uri_html}"{$rel}>{$link_uri_title_html}</a></p>
		</div>
	</div>
HTML;
		}

		$html .= <<<HTML
</div>
HTML;

		return $html . $edit_button;
	}
}

if ( !function_exists( 'st_af_cpt_shortcode' ) ) {
	function st_af_cpt_shortcode( $atts ) {
		$defaults = array(
			'id'   => null,
			'name' => '',
		);

		$atts = shortcode_atts( $defaults, $atts, st_af_cpt_get_shortcode_name() );

		if ( !absint( $atts[ 'id' ] ) && trim( $atts[ 'name' ] ) === '' ) {
			return '';
		}

		$post = st_af_cpt_find_post( $atts[ 'id' ], $atts[ 'name' ] );

		if ( !$post ) {
			return '';
		}

		return st_af_cpt_get_shortcode( $post );
	}
}

add_shortcode( st_af_cpt_get_shortcode_name(), 'st_af_cpt_shortcode' );

if ( !function_exists( 'st_af_cpt_columns' ) ) {

	function st_af_cpt_columns( $posts_columns ) {
		$rest_columns = array();

		foreach ( array( 'date' ) as $column ) {
			if ( !array_key_exists( $column, $posts_columns ) ) {
				continue;
			}

			$rest_columns[ $column ] = $posts_columns[ $column ];

			unset( $posts_columns[ $column ] );
		}

		$posts_columns[ 'shortcode' ] = 'ショートコード';

		$posts_columns = array_merge( $posts_columns, $rest_columns );

		return $posts_columns;
	}
}

add_action( 'manage_' . st_af_cpt_get_post_type_name() . '_posts_columns', 'st_af_cpt_columns' );

if ( !function_exists( 'st_af_cpt_shortcode_column' ) ) {

	function st_af_cpt_shortcode_column( $column_name, $post_id ) {
		switch ( $column_name ) {
			case 'shortcode':
				printf( '<code>[%s id="%s"]</code>', esc_html( st_af_cpt_get_shortcode_name() ), esc_html( $post_id ) );

				$post = get_post( $post_id );

				if ( trim( $post->post_name ) !== '' ) {
					printf(
							'<br><code>[%s name="%s"]</code>',
							esc_html( st_af_cpt_get_shortcode_name() ),
							esc_html( $post->post_name )
					);
				}

				break;

			default:
				break;
		}
	}
}

add_action(
	'manage_' . st_af_cpt_get_post_type_name() . '_posts_custom_column',
	'st_af_cpt_shortcode_column',
	10,
	2
);

require __DIR__ . '/template-tags.php';
