<?php
namespace St\Plugin\Blocks;

use St\Plugin\Blocks\Gutenberg\Gutenberg_Subscriber;
use St\Plugin\Blocks\Plugin\Plugin;
use St\Plugin\Blocks\Plugin\Plugin_Meta;

/**
 * @param string $file
 *
 * @return mixed[]
 */
function configure_container( $file ) {
	// Plugin Meta.
	$plugin_meta = new Plugin_Meta( $file );

	// Gutenberg.
	$gutenberg_subscriber = new Gutenberg_Subscriber( $plugin_meta );

	$subscribers = [
		'gutenberg' => $gutenberg_subscriber,
	];

	// Plugin.
	$plugin = new Plugin( $plugin_meta, $subscribers );

	// Container.
	$container = [
		'plugin_meta' => $plugin_meta,
		'plugin'      => $plugin,
		'subscribers' => $subscribers,
	];

	return $container;
}

/**
 * @param array<string, mixed> $container
 */
function exporse_container( array $container ) {
	$GLOBALS[ ST_BLOCKS ] = $container;
}

/**
 * @param string $file
 *
 * @return Plugin
 */
function configure( $file ) {
	if ( defined( 'ST_BLOCKS' ) ) {
		return get_plugin();
	}

	define( 'ST_BLOCKS_API_VERSION', '1.0.0' );
	define( 'ST_BLOCKS_API_PREFIX', 'st_blocks' );
	define( 'ST_BLOCKS_API_SLUG', 'st-blocks' );

	$container   = configure_container( $file );
	$plugin_meta = $container['plugin_meta'];

	/**
	 * @var string
	 */
	define( 'ST_BLOCKS', $plugin_meta->get_prefix() );

	exporse_container( $container );

	return $container['plugin'];
}

/**
 * @return array<string, mixed>|null
 */
function get_container() {
	if ( ! defined( 'ST_BLOCKS' ) ) {
		return null;
	}

	return $GLOBALS[ ST_BLOCKS ];
}

/**
 * @param string $id
 *
 * @return mixed|null
 */
function get( $id ) {
	$container = get_container();

	if ( $container === null ) {
		return null;
	}

	return isset( $container[ $id ] ) ? $container[ $id ] : null;
}

/**
 * @return Plugin|null
 */
function get_plugin() {
	return get( 'plugin' );
}

/**
 * @param Plugin|null $plugin
 */
function register( Plugin $plugin = null ) {
	static $registered = false;

	if ( $registered ) {
		return;
	}

	$plugin = ( $plugin !== null ) ? $plugin : get_plugin();

	if ( $plugin === null ) {
		return;
	}

	$plugin->register();

	$registered = true;
}

/**
 * @param Plugin|null $plugin
 */
function boot( Plugin $plugin = null ) {
	static $booted = false;

	if ( $booted ) {
		return;
	}

	$plugin = ( $plugin !== null ) ? $plugin : get_plugin();

	if ( $plugin === null ) {
		return;
	}

	$plugin->boot();

	$booted = true;
}

/**
 * @param Plugin|null $plugin
 */
function run( Plugin $plugin = null ) {
	register( $plugin );
	boot( $plugin );
}
