<?php
namespace St\Plugin\Blocks\Plugin;

/**
 * Class Plugin_Meta.
 *
 * @package St\Plugin\Blocks\Plugin
 */
class Plugin_Meta {
	/**
	 * @var string
	 */
	private $version;
	/**
	 * @var string
	 */
	private $file;
	/**
	 * @var string
	 */
	private $url;
	/**
	 * @var string
	 */
	private $dir;
	/**
	 * @var string
	 */
	private $slug;
	/**
	 * @var string
	 */
	private $prefix;

	/**
	 * Plugin_Meta constructor.
	 *
	 * @param string $file
	 */
	public function __construct( $file ) {
		require_once ABSPATH . 'wp-admin/includes/plugin.php';

		$this->file = $file;
		$this->dir  = plugin_dir_path( $file );
		$this->url  = plugin_dir_url( $file );

		$slug = basename( $this->dir );
		$slug = preg_replace( '/[^a-zA-Z0-9]+/', '-', $slug );
		$slug = preg_replace( '/([a-z])([A-Z])/', '$1-$2', $slug );
		$slug = trim( $slug, '-' );

		$this->slug   = strtolower( $slug );
		$this->prefix = str_replace( '-', '_', $this->slug );

		$data = get_plugin_data( $this->file, false, false );

		$this->name    = $data['Name'];
		$this->version = $data['Version'];
	}

	/**
	 * @return string
	 */
	public function get_name() {
		return $this->name;
	}

	/**
	 * @return string
	 */
	public function get_version() {
		return $this->version;
	}

	/**
	 * @return string
	 */
	public function get_file() {
		return $this->file;
	}

	/**
	 * @return string
	 */
	public function get_url() {
		return $this->url;
	}

	/**
	 * @return string
	 */
	public function get_dir() {
		return $this->dir;
	}

	/**
	 * @return string
	 */
	public function get_slug() {
		return $this->slug;
	}

	/**
	 * @return string
	 */
	public function get_prefix() {
		return $this->prefix;
	}
}
