<?php
namespace St\Plugin\Blocks\Plugin;

use St\Plugin\Blocks\Bootable_Interface;
use St\Plugin\Blocks\Event_Listener_Interface;

/**
 * Class Plugin.
 *
 * @package St\Plugin\Blocks\Plugin
 */
class Plugin implements Bootable_Interface {
	/**
	 * @var Plugin_Meta
	 */
	private $plugin_meta;
	/**
	 * @var Event_Listener_Interface[]
	 */
	private $subscribers;

	/**
	 * Plugin constructor.
	 *
	 * @param Plugin_Meta $plugin_meta
	 * @param array<int|string, Event_Listener_Interface> $subscribers
	 */
	public function __construct(
		Plugin_Meta $plugin_meta,
		array $subscribers = []
	) {
		$this->plugin_meta = $plugin_meta;
		$this->subscribers = $subscribers;
	}

	/**
	 * @return Plugin_Meta
	 */
	public function getMeta() {
		return $this->plugin_meta;
	}

	/**
	 * @return $this
	 */
	public function register() {
		register_activation_hook( $this->plugin_meta->get_file(), [ $this, 'activate' ] );
		register_deactivation_hook( $this->plugin_meta->get_file(), [ $this, 'deactivate' ] );

		return $this;
	}

	/**
	 * @return $this
	 */
	public function activate() {
		do_action( ST_BLOCKS_API_PREFIX . '_activate' );

		return $this;
	}

	/**
	 * @return $this
	 */
	public function boot() {
		foreach ( $this->subscribers as $subscriber ) {
			if ( $subscriber instanceof Event_Listener_Interface ) {
				$subscriber->subscribe();
			}
		}

		do_action( ST_BLOCKS_API_PREFIX . '_boot' );

		return $this;
	}

	/**
	 * @return $this
	 */
	public function deactivate() {
		do_action( ST_BLOCKS_API_PREFIX . '_deactivate' );

		return $this;
	}
}
